package de.mlessmann.certassist.openssl;

import java.nio.file.Path;

/**
 * Instance of a certificate that is temporarily stored on disk to be available for use in command line calls.
 * The instance implements AutoCloseable to enable cleanup after the stored files are no longer needed.
 * @implSpec The files should be removed from disk when the instance is closed, UNLESS the provided paths are the permanent storage location for the certificate files.
 */
public interface CertificateUsage extends AutoCloseable {
    Path certificatePath();
    Path certificateKeyPath();
    String fingerprint();

    @Override
    void close();
}
